@@ -21,6 +21,6 @@ class JSON(Response):
     media_type = "application/json"
 
     def render(self, content: typing.Any) -> bytes:
-        orjson.dumps(
+        return orjson.dumps(
             content
         )
